@@ -13,11 +13,11 @@ Genealogy::ObituaryDailyTimes - Lookup an entry in the Obituary Daily Times
 
 =head1 VERSION
 
-Version 0.12
+Version 0.13
 
 =cut
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 =head1 SYNOPSIS
 
@@ -53,14 +53,15 @@ sub new {
 		return bless { %{$class}, %args }, ref($class);
 	}
 
-	if(!defined((my $directory = ($args{'directory'} || $Database::Abstraction::init->{'directory'})))) {
+	my $directory = $args{'directory'} || $Database::Abstraction{'defaults'}{'directory'};
+	if(!defined($directory)) {
 		# If the directory argument isn't given, see if we can find the data
-		$directory ||= Module::Info->new_from_loaded(__PACKAGE__)->file();
+		$directory = Module::Info->new_from_loaded(__PACKAGE__)->file();
 		$directory =~ s/\.pm$//;
 		$args{'directory'} = File::Spec->catfile($directory, 'data');
 	}
-	if(!-d $args{'directory'}) {
-		Carp::carp(__PACKAGE__, ': ', $args{'directory'}, ' is not a directory');
+	if(!-d $directory) {
+		Carp::carp(__PACKAGE__, ": $directory is not a directory");
 		return;
 	}
 
@@ -84,10 +85,9 @@ sub new {
 
 sub search {
 	my $self = shift;
+	my $params = $self->_get_params('last', @_);
 
-	my %params = (ref($_[0]) eq 'HASH') ? %{$_[0]} : @_;
-
-	if(!defined($params{'last'})) {
+	if(!defined($params->{'last'})) {
 		Carp::carp("Value for 'last' is mandatory");
 		return;
 	}
@@ -99,13 +99,13 @@ sub search {
 	}
 
 	if(wantarray) {
-		my @obituaries = @{$self->{'obituaries'}->selectall_hashref(\%params)};
+		my @obituaries = @{$self->{'obituaries'}->selectall_hashref($params)};
 		foreach my $obit(@obituaries) {
 			$obit->{'url'} = _create_url($obit);
 		}
 		return @obituaries;
 	}
-	if(defined(my $obit = $self->{'obituaries'}->fetchrow_hashref(\%params))) {
+	if(defined(my $obit = $self->{'obituaries'}->fetchrow_hashref($params))) {
 		$obit->{'url'} = _create_url($obit);
 		return $obit;
 	}
@@ -139,6 +139,38 @@ sub _create_url {
 	Carp::croak(__PACKAGE__, ": Invalid source, '$source'");
 }
 
+# Helper routine to parse the arguments given to a function,
+#	allowing the caller to call the function in anyway that they want
+#	e.g. foo('bar'), foo(arg => 'bar'), foo({ arg => 'bar' }) all mean the same
+#	when called _get_params('arg', @_);
+sub _get_params
+{
+	my $self = shift;
+	my $default = shift;
+
+	my %rc;
+
+	if(ref($_[0]) eq 'HASH') {
+		%rc = %{$_[0]};
+	} elsif(scalar(@_) % 2 == 0) {
+		%rc = @_;
+	} elsif(scalar(@_) == 1) {
+		if(defined($default)) {
+			$rc{$default} = shift;
+		} else {
+			my @c = caller(1);
+			my $func = $c[3];	# calling function name
+			Carp::croak('Usage: ', __PACKAGE__, "->$func($default => " . '$val)');
+		}
+	} elsif((scalar(@_) == 0) && defined($default)) {
+		my @c = caller(1);
+		my $func = $c[3];	# calling function name
+		Carp::croak('Usage: ', __PACKAGE__, "->$func($default => " . '$val)');
+	}
+
+	return \%rc;
+}
+
 =head1 AUTHOR
 
 Nigel Horne, C<< <njh at bandsman.co.uk> >>
